You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airavata.apache.org by sc...@apache.org on 2015/07/29 19:48:45 UTC

[13/50] [abbrv] airavata-php-gateway git commit: fixing AIRAVATA-1782

fixing AIRAVATA-1782


Project: http://git-wip-us.apache.org/repos/asf/airavata-php-gateway/repo
Commit: http://git-wip-us.apache.org/repos/asf/airavata-php-gateway/commit/ad554028
Tree: http://git-wip-us.apache.org/repos/asf/airavata-php-gateway/tree/ad554028
Diff: http://git-wip-us.apache.org/repos/asf/airavata-php-gateway/diff/ad554028

Branch: refs/heads/master
Commit: ad55402844840a4166fe16fbdaadad6f54a2be2f
Parents: c8e0d6a
Author: Supun Nakandala <sc...@apache.org>
Authored: Sat Jul 18 16:33:00 2015 +0530
Committer: Supun Nakandala <sc...@apache.org>
Committed: Sat Jul 18 16:33:00 2015 +0530

----------------------------------------------------------------------
 app/views/resource/edit.blade.php | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/airavata-php-gateway/blob/ad554028/app/views/resource/edit.blade.php
----------------------------------------------------------------------
diff --git a/app/views/resource/edit.blade.php b/app/views/resource/edit.blade.php
index 42d8bee..396893b 100644
--- a/app/views/resource/edit.blade.php
+++ b/app/views/resource/edit.blade.php
@@ -518,8 +518,8 @@
             <select name="dataMovementProtocol" class="form-control selected-data-movement-protocol">
                 <option></option>
                 @foreach( $dataMovementProtocols as $index => $dmp)
-                //GridFTP is not supported in Airavata backend. Therefore commenting out from UI
-                @if( ! in_array( $index, $addedDMI) && $dmp!="GridFTP")
+                //GridFTP and SFTP not supported in Airavata backend. Therefore commenting out from UI
+                @if( ! in_array( $index, $addedDMI) && $dmp!="GridFTP" && $dmp!="SFTP")
                 <option value="{{ $index }}">{{ $dmp }}</option>
                 @endif
                 @endforeach
@@ -578,14 +578,14 @@
         </select>
     </div>
 
-    <div class="form-group required">
-        <label class="control-label">Select Monitoring Mode </label>
-        <select name="monitorMode" required>
-            @foreach( $monitorModes as $index => $mode)
-            <option value="{{ $index }}">{{ $mode}}</option>
-            @endforeach
-        </select>
-    </div>
+<!--    <div class="form-group required">-->
+<!--        <label class="control-label">Select Monitoring Mode </label>-->
+<!--        <select name="monitorMode" required>-->
+<!--            @foreach( $monitorModes as $index => $mode)-->
+<!--            <option value="{{ $index }}">{{ $mode}}</option>-->
+<!--            @endforeach-->
+<!--        </select>-->
+<!--    </div>-->
 
     <div class="form-group addedScpValue hide">
         <label class="control-label">Alternate SSH Host Name</label>